# `/app/static/img/uploaded`

Images that were uploaded in the admin interface live here.

## Subdirectories

- `_deleted`: All deleted images live here.  This directory is `.gitignore`d, but will not empty on it's own.  It's contents should be removed periodically in production.